==> oddmuse-1.464.tar.gz: oddmuse-1.464/russian-utf8.pl <==
# UTF-8 encoded Russian language file for use with Oddmuse
#
# Copyright (c) 2003  Zajcev Evgeny
# Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This script was last checked for Oddmuse version 1.383.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
Невозможно создать %s
Invalid UserName %s: not saved.
Hекорректная кличка %s: ничего не записано.
UserName must be 50 characters or less: not saved

XML::RSS is not available on this system.

diff
отличия
history
история
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to edit this page
Щелчок - создать эту страницу
Invalid action parameter %s
Некорректный параметр действия %s
Invalid URL.
Некорректный URL.
Page name is missing

Page name is too long: %s
Имя страницы слишком велико: %s
Invalid Page %s
Некорректная страница %s
Invalid Page %s (must not end with .db)
Некорректная страница %s (не должна оканчиваться на .db)
Invalid Page %s (must not end with .lck)
Некорректная страница %s (Некорректная страница %s lck)
Page name may not contain space characters: %s
Имя страницы не может содержать пробельные символы: %s
Preview:
Предпросмотр:
Preview only, not yet saved
Только предпросмотр - пока ничего не записано
Please go on to %s.

Could not open %s log file
Не возможно открыть файл протокола %s 
Error was
Были ошибки 
Note: This error is normal if no changes have been made.
Примечание: Эта ошибка - нормально, если не было сделано изменений.
Could not open old %s log file
Не возможно открыть старый файл протокола %s 
No updates since %s
Не было обновлений с %s
Updates since %s
Обновления с %s
Updates in the last %s days
Обновления за последние %s дней
Updates in the last %s day
Обновления за последний %s день
for %s only
только для %s
List latest change per page only
Перечислить только последнее изменение на страницу
List all changes
Перечислить все изменения
List only major changes
Перечислить только значительные изменения
Include minor changes
Включить незначительные изменения
%s days
%s дней
List later changes
Перечислить недавние изменения
Filters
Фильтры
Username:
Имя пользователя:
Host:
Хост:
Language:

Go!
Вперёд!
(minor)
(незначительные)
rollback
откат
new

from %s
с %s
History of %s
История %s
Compare
Сравнить
Revision %s
Версия %s
by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]
[Домой]
redirected from %s
перенаправлено с %s
Click to search for references to this page
Щелчок - искать ссылки на эту страницу
Cookie: 

Warning
Внимание
Database is stored in temporary directory %s
База данных сохранена во временной директории %s
%s seconds

The same page on other sites:

EditNearLinks

Last edited
Последнее редактирование
Edited
Правленное
by %s

(diff)
(отличия)
Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
Комментарии к этой странице
Edit revision %s of this page
Править версию %s этой страницы
Edit text of this page
Редактировать текст этой страницы
e

This page is read-only
Эта страница предназначена только для чтения
View other revisions
Смотреть другие версии
View current revision
Смотреть текущую версию
View all changes
Смотреть все изменения
Back to %s
Назад к %s
new comment
новый комментарий
s

Save
Сохранить
Preview
Предпросмотр
Search:
Поиск:
Replace:
Замена:
Validate HTML

Validate CSS

Difference (from revision %1 to %2)
Отличия (от версии %1 до %2)
revision %s
версии %s
current revision
текущей версии
Difference (from prior %s revision)
Отличия (текущей версии от предыдущей - %s)
major
значительные
minor
незначительные
No diff available.
Отличий нет.
Changed:
Изменилось:
Removed:
Удалено:
Added:
Добавлено:
to

Revision %s not available
Версия %s не доступна
showing current revision instead
отображение текущей версии вместо
Showing revision %s
Показ версии %s
Cannot save an nameless page.

Cannot open %s

Cannot write %s

Could not get %s lock

Unlocking

This operation may take several seconds...
Это может занять несколько секунд, так что не нервничайте
Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Editing Denied
Редактирование запрещено
Editing not allowed: user, ip, or network is blocked.
Редактирование не разрешено: пользователь, IP или сеть заблокированы.
Contact the wiki administrator for more information.
Свяжитесь с нашей администрацией чтоб узнать больше.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
Редактирование не допустимо: %s только для чтения.
Only administrators can upload files.

Editing revision %s of
Редактирование версии %s
Editing %s
Редактирование %s
Editing old revision %s.
Редактирование старой версии %s.
Saving this page will replace the latest revision with this text.
Сохранение этой страницы заменит последнюю версию на этот текст.
Summary:
Итого:
This change is a minor edit.
Это изменение является незначительной правкой.
Replace this file with text.
Заменить этот файл текстом.
Replace this text with a file.
Заменить этот текст файлом.
File to upload: 

Files of type %s are not allowed.

Password
Пароль
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваш пароль сохраняется в cookie, если cookies у вас включены. Cookies могут быть потеряны, если вы подключаетесь с другого компьютера, с другой учётной записи, или используя другое программное обеспечение.
You are currently an administrator on this site.
Теперь вы - администратор на этом сайте.
You are currently an editor on this site.
Теперь вы - редактор на этом сайте.
You are a normal user on this site.
Вы - обычный пользователь на этом сайте.
Your password does not match any of the  administrator or editor passwords.
Ваш пароль не совпадает с паролями администратора или редактора.
Password:
Пароль:
This site does not use admin or editor passwords.
Этот сайт не использует пароли администратора или редактора.
This operation is restricted to site editors only...
Эта операция только для редакторов сайта...
This operation is restricted to administrators only...
Эта операция только для администаторов сайта...
Rule "%1" matched "%2" on this page.

Index of all pages
Каталог всех страниц:
all pages
все страницы
permanent anchors
неизменные якори
near links

(for %s)
(%s)
%s pages found.
Найдено %s страниц.
Replaced: %s

Search for: %s
Искать: %s
View changes for these pages
Смотреть изменения этих страниц
Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Editing not allowed for %s.
Редактирование не разрешено для %s.
SampleUndefinedPage
ПримерПроизвольнойСтраницы
%s cannot be defined.
%s невозможно определить.
Sample_Undefined_Page
Пример_Произвольной_Страницы
[[%s]] cannot be defined.
[[%s]] невозможно определить
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Could not get a lock to merge!

you

ancestor

other

Maintenance on all pages

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Inter links:

Near links:

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Recent Visitors

Referrers

All Referrers

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Footnotes:

image: %s

Index

Languages:

Show!

Define

Full Link List
Полный список ссылок
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

Static Copy

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
альтернативный
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
поиск
Blog

END_OF_TRANSLATION

==> oddmuse-1.524.tar.gz: oddmuse-1.524/russian-utf8.pl <==
# UTF-8 encoded Russian language file for use with Oddmuse
#
# Copyright (c) 2003  Zajcev Evgeny
# Copyright (C) 2004  Andrei Bulava <abulava@users.sourceforge.net>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This script was last checked for Oddmuse version 1.383.
#
$ModulesDescription .= '<p>$Id: russian-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.

Could not create %s
Невозможно создать %s
Invalid UserName %s: not saved.
Hекорректная кличка %s: ничего не записано.
UserName must be 50 characters or less: not saved

This page contains an uploaded file:

XML::RSS is not available on this system.

diff
отличия
history
история
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page
Щелчок - создать эту страницу
image

download

Invalid action parameter %s
Некорректный параметр действия %s
Invalid URL.
Некорректный URL.
Page name is missing

Page name is too long: %s
Имя страницы слишком велико: %s
Invalid Page %s
Некорректная страница %s
Invalid Page %s (must not end with .db)
Некорректная страница %s (не должна оканчиваться на .db)
Invalid Page %s (must not end with .lck)
Некорректная страница %s (Некорректная страница %s lck)
Page name may not contain space characters: %s
Имя страницы не может содержать пробельные символы: %s
Preview:
Предпросмотр:
Preview only, not yet saved
Только предпросмотр - пока ничего не записано
Please go on to %s.

Could not open %s log file
Не возможно открыть файл протокола %s 
Error was
Были ошибки 
Note: This error is normal if no changes have been made.
Примечание: Эта ошибка - нормально, если не было сделано изменений.
Could not open old %s log file
Не возможно открыть старый файл протокола %s 
No updates since %s
Не было обновлений с %s
Updates since %s
Обновления с %s
Updates in the last %s days
Обновления за последние %s дней
Updates in the last %s day
Обновления за последний %s день
for %s only
только для %s
List latest change per page only
Перечислить только последнее изменение на страницу
List all changes
Перечислить все изменения
List only major changes
Перечислить только значительные изменения
Include minor changes
Включить незначительные изменения
%s days
%s дней
List later changes
Перечислить недавние изменения
Filters
Фильтры
Username:
Имя пользователя:
Host:
Хост:
Language:

Go!
Вперёд!
(minor)
(незначительные)
rollback
откат
new

from %s
с %s
History of %s
История %s
Compare
Сравнить
Revision %s
Версия %s
by

Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Каталог всех страниц:
Wiki Version

Unlock Wiki

Recent Visitors

Password
Пароль
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Домой]
redirected from %s
перенаправлено с %s
Click to search for references to this page
Щелчок - искать ссылки на эту страницу
Cookie: 

Warning
Внимание
Database is stored in temporary directory %s
База данных сохранена во временной директории %s
%s seconds

The same page on other sites:

EditNearLinks

Last edited
Последнее редактирование
Edited
Правленное
by %s

(diff)
(отличия)
Edit revision %s of this page
Править версию %s этой страницы
Edit this page
Редактировать текст этой страницы
e

This page is read-only
Эта страница предназначена только для чтения
View other revisions
Смотреть другие версии
View current revision
Смотреть текущую версию
View all changes
Смотреть все изменения
new comment
новый комментарий
Homepage URL:

s

Save
Сохранить
Preview
Предпросмотр
Search:
Поиск:
f

Replace:
Замена:
Validate HTML

Validate CSS

Difference (from revision %1 to %2)
Отличия (от версии %1 до %2)
revision %s
версии %s
current revision
текущей версии
Difference (from prior %s revision)
Отличия (текущей версии от предыдущей - %s)
major
значительные
minor
незначительные
No diff available.
Отличий нет.
Old revision:

Changed:
Изменилось:
Removed:
Удалено:
Added:
Добавлено:
to

Revision %s not available
Версия %s не доступна
showing current revision instead
отображение текущей версии вместо
Showing revision %s
Показ версии %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Could not get %s lock

This operation may take several seconds...
Это может занять несколько секунд, так что не нервничайте
Forced unlock of %s lock.

No unlock required.

%s hours ago

1 hour ago

%s minutes ago

1 minute ago

%s seconds ago

1 second ago

just now

Editing Denied
Редактирование запрещено
Editing not allowed: user, ip, or network is blocked.
Редактирование не разрешено: пользователь, IP или сеть заблокированы.
Contact the wiki administrator for more information.
Свяжитесь с нашей администрацией чтоб узнать больше.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
Редактирование не допустимо: %s только для чтения.
Only administrators can upload files.

Editing revision %s of
Редактирование версии %s
Editing %s
Редактирование %s
Editing old revision %s.
Редактирование старой версии %s.
Saving this page will replace the latest revision with this text.
Сохранение этой страницы заменит последнюю версию на этот текст.
Summary:
Итого:
This change is a minor edit.
Это изменение является незначительной правкой.
Replace this file with text.
Заменить этот файл текстом.
Replace this text with a file.
Заменить этот текст файлом.
File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Ваш пароль сохраняется в cookie, если cookies у вас включены. Cookies могут быть потеряны, если вы подключаетесь с другого компьютера, с другой учётной записи, или используя другое программное обеспечение.
You are currently an administrator on this site.
Теперь вы - администратор на этом сайте.
You are currently an editor on this site.
Теперь вы - редактор на этом сайте.
You are a normal user on this site.
Вы - обычный пользователь на этом сайте.
Your password does not match any of the  administrator or editor passwords.
Ваш пароль не совпадает с паролями администратора или редактора.
Password:
Пароль:
This site does not use admin or editor passwords.
Этот сайт не использует пароли администратора или редактора.
This operation is restricted to site editors only...
Эта операция только для редакторов сайта...
This operation is restricted to administrators only...
Эта операция только для администаторов сайта...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(%s)
%s pages found.
Найдено %s страниц.
Replaced: %s

Search for: %s
Искать: %s
View changes for these pages
Смотреть изменения этих страниц
Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated

Complete Content

The main page is %s.

Comments on this page
Комментарии к этой странице
Editing not allowed for %s.
Редактирование не разрешено для %s.
SampleUndefinedPage
ПримерПроизвольнойСтраницы
%s cannot be defined.
%s невозможно определить.
Sample_Undefined_Page
Пример_Произвольной_Страницы
[[%s]] cannot be defined.
[[%s]] невозможно определить
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous

Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Main lock obtained.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted

Moving part of the %s log file.

Moving %s log entries.

Getting page index file for %s.

Main lock released.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Missing page id to lock/unlock...

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s

Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
Полный список ссылок
Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers

Referrers

Updating %s

Search term missing.

Static Copy

Back to %s
Назад к %s
Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
альтернативный
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
поиск
Blog

END_OF_TRANSLATION
